%define libdir32 %{_exec_prefix}/lib
%define platform pc
%define efi 1

%global efi %{ix86} x86_64
%define tarversion	2.00

# build documentation by default
%bcond_without  doc


Summary:	GNU GRUB is a Multiboot boot loader
Name:		grub2
Version:	2.02
Release:	%mkrel 4
License:	GPLv3+
Group:		System/Kernel and hardware
Url:		http://www.gnu.org/software/grub/
Source0:	grub-%{tarversion}.tar.xz
Source1:	90_persistent
Source2:	grub.default.pclinuxos
Source5:	grub2.filter
Source6:	grub2.script
Source8:	grub2-po-update.tar.gz
Source9:	update-grub
Source12:	42_efi
Source14:	grub2-cfg-mod
Source15:	unicode.pf2
Source16:	93_memtest

#mga
Patch0:		grub2-2.00-bzrignore.patch
Patch1:		grub2-2.00-mga-git-9752.patch
Patch2:		grub-2.00-minilzo.patch
Patch3:		grub2-2.00-mga-grub-mkconfig_lib.in.patch

#fedora EFI patches
Patch0091: 	0091-Add-support-for-linuxefi.patch
Patch0092: 	0092-Use-linuxefi-and-initrdefi-where-appropriate.patch
Patch0112: 	0112-Add-support-for-UEFI-operating-systems-returned-by-o.patch
Patch0118:	0118-Don-t-say-GNU-Linux-in-generated-menus.patch
Patch0129: 	0129-Make-CTRL-and-ALT-keys-work-as-expected-on-EFI-syste.patch
Patch0140: 	0140-always-return-error-to-UEFI.patch
Patch0146:	0146-Generate-OS-and-CLASS-in-10_linux-from-etc-os-releas.patch

#mga
Patch0450:	0450-Pass-x-hex-hex-straight-through-unmolested.patch
Patch0451:	0451-Fix-crash-on-http.patch
Patch0460:	0460-blscfg-add-blscfg-module-to-parse-Boot-Loader-Specif.patch
Patch0476:	0476-Use-the-correct-indentation-for-the-term-help-text.patch

BuildRequires:	autogen
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	fonts-ttf-unifont
BuildRequires:	help2man
BuildRequires:	ruby
BuildRequires:	texinfo
BuildRequires:	glibc-static-devel
BuildRequires:	liblzo-devel
BuildRequires:	pkgconfig(devmapper)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(liblzma)
BuildRequires:	pkgconfig(libusb)
BuildRequires:	pkgconfig(ncurses)

Requires(post):	os-prober
Provides:	bootloader
Provides:	grub2bootloader
Requires:	grub2-theme-pclinuxos


%description
GNU GRUB is a Multiboot boot loader. It was derived from GRUB, the
GRand Unified Bootloader, which was originally designed and implemented
by Erich Stefan Boleyn.

Briefly, a boot loader is the first software program that runs when a
computer starts. It is responsible for loading and transferring control
to the operating system kernel software (such as the Hurd or Linux).
The kernel, in turn, initializes the rest of the operating system (e.g. GNU).


%ifarch %{efi}
%package efi
Summary:	GRUB for EFI systems
Group:		System/Kernel and hardware
Requires(post):	efibootmgr

%description efi
The GRand Unified Bootloader (GRUB) is a highly configurable and customizable
bootloader with modular architecture.

It support rich variety of kernel formats, file systems, computer 
architectures and hardware devices.  This subpackage provides support 
for EFI systems.
%endif

%package doc
Summary:	GRUB Documentation
Group:		Documentation
BuildArch:	noarch

%description doc
Documentation for the The GRand Unified Bootloader (GRUB) bootloader.


%prep
%setup -q -n grub-%{tarversion}
%apply_patches

perl -pi -e 's/(\@image\{font_char_metrics,,,,)\.(png\})/$1$2/;' \
        docs/grub-dev.texi

sed -ri -e 's/-g"/"/g' -e "s/-Werror//g" configure.ac

perl -pi -e 's/-Werror//;' grub-core/Makefile.am
export GRUB_CONTRIB="$PWD/grub-extras"
aclocal --force -Im4 -I/usr/share/aclocal --install
./autogen.sh

tar -xf %{SOURCE8}
pushd po-update; sh ./update.sh; popd
cd ..

%build
export CONFIGURE_TOP="$PWD"
%ifarch %{efi}
mkdir -p efi
pushd efi
%configure2_5x \
	CFLAGS="" \
	TARGET_LDFLAGS=-static \
	--with-platform=efi \
	--program-transform-name=s,grub,%{name}-efi, \
	--libdir=%{libdir32} \
	--libexecdir=%{libdir32} \
	--with-grubdir=grub2 \
	--disable-werror \
	--enable-grub-emu-usb \
	--enable-grub-mkfont
%make all

%if %{with doc}
make html
%endif

%ifarch %{ix86}
%define grubefiarch i386-efi
%else
%define grubefiarch %{_arch}-efi
%endif

COMMON_MODULES="
	appleldr boot chain configfile echo efi_gop efi_uga halt linux linuxefi loadbios loadenv minicmd normal reboot search test
	all_video font gfxmenu gfxterm png
	part_apple part_gpt part_msdos
	btrfs ext2 fat hfsplus reiserfs xfs
	lvm mdraid09 mdraid1x
"
./grub-mkimage -O %{grubefiarch} -p /EFI/pclos/%{name}-efi -o grub.efi -d grub-core ${COMMON_MODULES}
./grub-mkimage -O %{grubefiarch} -p /BOOT/EFI -o grubcd.efi -d grub-core ${COMMON_MODULES} iso9660

popd
%endif

mkdir -p pc
cd pc
%configure2_5x \
	CFLAGS="" \
	TARGET_LDFLAGS=-static \
	--with-platform=pc \
    %ifarch x86_64
	--enable-efiemu \
    %endif
	--program-transform-name=s,grub,%{name}, \
	--libdir=%{libdir32} \
	--libexecdir=%{libdir32} \
	--with-grubdir=grub2 \
	--disable-werror \
	--enable-grub-emu-usb \
	--enable-grub-mkfont
%make all

%if %{with doc}
make html
%endif

%install
%ifarch %{efi}
cd efi
%makeinstall_std

%if %{with doc}
%makeinstall_std -C docs install-html
%endif

mv %{buildroot}%{_infodir}/grub.info %{buildroot}%{_infodir}/grub2.info

mv %{buildroot}/etc/bash_completion.d/grub %{buildroot}/etc/bash_completion.d/grub-efi

# Script that makes part of grub.cfg persist across updates
install -m 755 %{SOURCE1} %{buildroot}%{_sysconfdir}/grub.d/

# Ghost config file
 install -m 755 -d %{buildroot}/boot/efi/EFI/pclos/
 install -d %{buildroot}/boot/efi/EFI/pclos/%{name}-efi
 touch %{buildroot}/boot/efi/EFI/pclos/%{name}-efi/grub.cfg
 ln -s ../boot/efi/EFI/pclos/%{name}-efi/grub.cfg %{buildroot}%{_sysconfdir}/%{name}-efi.cfg

# Install ELF files modules and images were created from into
# the shadow root, where debuginfo generator will grab them from
find %{buildroot} -name '*.mod' -o -name '*.img' |
while read MODULE
do
        BASE=$(echo $MODULE |sed -r "s,.*/([^/]*)\.(mod|img),\1,")
        # Symbols from .img files are in .exec files, while .mod
        # modules store symbols in .elf. This is just because we
        # have both boot.img and boot.mod ...
        EXT=$(echo $MODULE |grep -q '.mod' && echo '.elf' || echo '.exec')
        TGT=$(echo $MODULE |sed "s,%{buildroot},.debugroot,")
#        install -m 755 -D $BASE$EXT $TGT
done
 install -m 755 grub.efi %{buildroot}/boot/efi/EFI/pclos/%{name}-efi/grub.efi
 install -m 755 grubcd.efi %{buildroot}/boot/efi/EFI/pclos/%{name}-efi/grubcd.efi
cd ..
%endif

######EFI

cd pc
%makeinstall_std

%if %{with doc}
%makeinstall_std -C docs install-html
%endif

mv -f %{buildroot}%{_docdir}/grub %{buildroot}%{_docdir}/%{name}

# (bor) grub.info is harcoded in sources
mv %{buildroot}%{_infodir}/grub.info %{buildroot}%{_infodir}/grub2.info

# Script that makes part of grub.cfg persist across updates
install -m 755 %{SOURCE1} %{buildroot}%{_sysconfdir}/grub.d/

# Ghost config file
install -d %{buildroot}/boot/%{name}
install -d %{buildroot}/boot/%{name}/locale
touch %{buildroot}/boot/%{name}/grub.cfg
ln -s ../boot/%{name}/grub.cfg %{buildroot}%{_sysconfdir}/%{name}.cfg

# Install ELF files modules and images were created from into
# the shadow root, where debuginfo generator will grab them from
find %{buildroot} -name '*.mod' -o -name '*.img' |
while read MODULE
do
        BASE=$(echo $MODULE |sed -r "s,.*/([^/]*)\.(mod|img),\1,")
        # Symbols from .img files are in .exec files, while .mod
        # modules store symbols in .elf. This is just because we
        # have both boot.img and boot.mod ...
        EXT=$(echo $MODULE |grep -q '.mod' && echo '.elf' || echo '.exec')
        TGT=$(echo $MODULE |sed "s,%{buildroot},.debugroot,")
#        install -m 755 -D $BASE$EXT $TGT
done


# Defaults
install -m 644 -D %{SOURCE2} %{buildroot}%{_sysconfdir}/default/grub

#Add more useful update-grub2 script
install -m 755 -D %{SOURCE9} %{buildroot}%{_bindir}/update-grub
ln -s %{_bindir}/update-grub %{buildroot}%{_bindir}/update-grub2


# Filetriggers
install -d %{buildroot}/%{_filetriggers_dir}
install -D %{SOURCE5} %{buildroot}/%{_filetriggers_dir}/%{name}.filter
install -D %{SOURCE6} %{buildroot}/%{_filetriggers_dir}/%{name}.script

# Windows EFI entry
install -m 755 %{SOURCE12} %{buildroot}%{_sysconfdir}/grub.d

# <akdengi> install programm to change option in /etc/default/grub
install -m 755 %{SOURCE14} %{buildroot}%{_sbindir}/grub2-cfg-mod

# Memtest
install -m 755 %{SOURCE16} %{buildroot}%{_sysconfdir}/grub.d

# Remove starfield theme
rm -rf %{buildroot}/%{_datadir}/grub/themes

# Font
install -d %{buildroot}/boot/%{name}/fonts

# Themes
install -d %{buildroot}/boot/%{name}/themes

%find_lang grub

%files -f pc/grub.lang
%{libdir32}/grub/*-%{platform}
%{_bindir}/grub2-file
%{_bindir}/grub2-mknetdir
%{_bindir}/grub2-render-label
%{_bindir}/grub2-syslinux2cfg
%{_sbindir}/grub2-macbless
%{_bindir}/update-grub
%{_bindir}/update-grub2
%{_bindir}/%{name}-mount
%{_bindir}/%{name}-editenv
%{_bindir}/%{name}-fstest
%{_bindir}/%{name}-kbdcomp
%{_bindir}/%{name}-menulst2cfg
%{_bindir}/%{name}-mkfont
%{_bindir}/%{name}-mkimage
%{_bindir}/%{name}-mklayout
%{_bindir}/%{name}-mkpasswd-pbkdf2
%{_bindir}/%{name}-mkrelpath
%{_bindir}/%{name}-mkrescue
%{_bindir}/%{name}-mkstandalone
%{_bindir}/%{name}-script-check
%{_sbindir}/%{name}-bios-setup
%{_sbindir}/%{name}-install
%{_sbindir}/%{name}-mkconfig
%{_sbindir}/%{name}-ofpathname
%{_sbindir}/%{name}-probe
%{_sbindir}/%{name}-reboot
%{_sbindir}/%{name}-set-default
%{_sbindir}/%{name}-sparc64-setup
%{_sbindir}/grub2-cfg-mod
%{_datadir}/grub
%attr(0700,root,root) %dir %{_sysconfdir}/grub.d
%{_sysconfdir}/grub.d/README
%config %{_sysconfdir}/grub.d/??_*
%{_sysconfdir}/%{name}.cfg
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/default/grub
%{_sysconfdir}/bash_completion.d/grub
%dir /boot/%{name}
%dir /boot/%{name}/locale
/boot/%{name}/grub.cfg
%{_infodir}/%{name}.info*
%{_infodir}/grub-dev.info*
%{_mandir}/*/%{name}-*
%exclude %{_mandir}/*/%{name}-efi-*

# RPM filetriggers
%{_filetriggers_dir}/%{name}.*

#Fonts
%dir /boot/%{name}/fonts

#Theme
%dir /boot/%{name}/themes


%ifarch %{efi}
%files efi
%attr(0755,root,root) %dir /boot/efi/EFI/pclos/grub2-efi
%attr(0755,root,root) /boot/efi/EFI/pclos/grub2-efi/grub.efi
%attr(0755,root,root) /boot/efi/EFI/pclos/grub2-efi/grubcd.efi
%attr(0755,root,rott) %ghost %config(noreplace) /boot/efi/EFI/pclos/grub2-efi/grub.cfg
%{libdir32}/grub/%{_arch}-efi/
%{_sbindir}/%{name}-efi*
%{_bindir}/%{name}-efi*
%{_bindir}/grub2-glue-efi
%{_mandir}/*/%{name}-efi-*
%config(noreplace) %{_sysconfdir}/%{name}-efi.cfg
%{_sysconfdir}/bash_completion.d/grub-efi
%endif

%files doc
%doc %{_docdir}/%{name}


%post
exec >/dev/null 2>&1
# Create device.map or reuse one from GRUB Legacy
cp -u /boot/grub/device.map /boot/%{name}/device.map 2>/dev/null ||
	%{_sbindir}/%{name}-mkdevicemap
# Determine the partition with /boot
BOOT_PARTITION=$(df -h /boot |(read; awk '{print $1; exit}'|sed 's/[[:digit:]]*$//'))
# (Re-)Generate core.img, but don't let it be installed in boot sector
%{_sbindir}/%{name}-install $BOOT_PARTITION
# Regenerate configure on install or update
%{_bindir}/update-grub2
#bugfix: error message before loading of grub2 menu on boot
cp -f /boot/grub2/locale/en@quot.mo /boot/grub2/locale/en.mo

#delete non-needing doubling rpmsave and rpmnew files
rm -f /etc/grub.d/*.rpmsave
rm -f /etc/grub.d/*.rpmnew

%preun
exec >/dev/null
if [ $1 = 0 ]; then
    # XXX Ugly
    rm -f /boot/%{name}/*.mod
    rm -f /boot/%{name}/*.img
    rm -f /boot/%{name}/*.lst
    rm -f /boot/%{name}/*.o
    rm -f /boot/%{name}/device.map
fi

#-----------------------------------------------------------------------


%changelog
* Wed Apr 29 2015 bb <bb> 2.02-4pclos2015
- add efi fedora patches
- sync to mga git 9752.18

* Tue Apr 28 2015 bb <bb> 2.02-3pclos2015
- sync with rosa 2.00-72
